@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: properties.c,v 1.48 2005/06/10 08:20:59 davyd Exp $
+ $Id: properties.c 10052 2006-11-15 16:57:08Z kmaraas $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,13 +28,15 @@
 #include <sys/file.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
+#ifdef HAVE_SYS_SYSCTL_H
 #include <sys/sysctl.h>
+#endif
 
+#ifdef HAVE_ERR_H
 #include <err.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
-#include <sys/file.h>
-#include <sys/ioctl.h>
 #include <time.h>
 #include <unistd.h>
 
@@ -81,43 +83,12 @@ soft_set_sensitive (GtkWidget *w, gboolean sensitivity)
 }
 #endif /* 0 */
 
-static void
-set_label_ptr (ProgressData *battstat)
-{
-	char *label;
-	int active;
-	
-	active = gtk_combo_box_get_active (GTK_COMBO_BOX (battstat->combo_ptr));
-
-	if (active == 0)
-		/* TRANSLATOR: this is the final word in the sentence:
-		 *   "Warn when percentage remaining is less then ?? percent"
-		 */
-		label = g_strdup (_("percent"));
-	else if (active == 1)
-	{
-		/* TRANSLATOR: this is the final word in the sentence:
-		 *   "Warn when time remaining is less then ?? minutes"
-		 */
-		label = g_strdup (ngettext ("minute", "minutes",
-					battstat->red_val));
-	}
-	else
-	{
-		g_warning ("Unknown value for combo_ptr!");
-		label = g_strdup ("??");
-	}
-
-	gtk_label_set_text (GTK_LABEL (battstat->label_ptr), label);
-	g_free (label);
-}
-
 static void
 combo_ptr_cb (GtkWidget *combo_ptr, gpointer data)
 {
 	ProgressData *battstat = data;
 	
-	if (gtk_combo_box_get_active (GTK_COMBO_BOX (battstat->combo_ptr)))
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (combo_ptr)))
 		battstat->red_value_is_time = TRUE;
 	else
 		battstat->red_value_is_time = FALSE;
@@ -126,17 +97,15 @@ combo_ptr_cb (GtkWidget *combo_ptr, gpointer data)
 			"red_value_is_time",
 			battstat->red_value_is_time,
 			NULL);
-	
-	set_label_ptr (battstat);
 }
 
 static void
-spin_ptr_cb (GtkWidget *combo_ptr, gpointer data)
+spin_ptr_cb (GtkWidget *spin_ptr, gpointer data)
 {
 	ProgressData *battstat = data;
 
 	battstat->red_val = gtk_spin_button_get_value_as_int (
-			GTK_SPIN_BUTTON (battstat->spin_ptr));
+			GTK_SPIN_BUTTON (spin_ptr));
 	/* automatically calculate orangle and yellow values from the
 	 * red value
 	 */
@@ -150,8 +119,6 @@ spin_ptr_cb (GtkWidget *combo_ptr, gpointer data)
 			"red_value",
 			battstat->red_val,
 			NULL);
-
-	set_label_ptr (battstat);
 }
 
 static gboolean
@@ -246,27 +213,6 @@ show_text_toggled (GtkToggleButton *button, gpointer data)
   				 battstat->showtext, NULL);
 }
 
-static void
-suspend_changed (GtkEditable *editable, gpointer data)
-{
-  ProgressData   *battstat = data;
-  PanelApplet *applet = PANEL_APPLET (battstat->applet);
-  gchar *cmd;
-  
-  cmd = gtk_editable_get_chars (editable, 0, -1);
-  if (!cmd)
-  	return;
-  
-  if (battstat->suspend_cmd)
-    g_free (battstat->suspend_cmd);
-  battstat->suspend_cmd = g_strdup(cmd);
-  g_free (cmd);
-  
-  panel_applet_gconf_set_string (applet, "suspend_command", 
-  				 battstat->suspend_cmd, NULL);
-
-}
-
 static void
 lowbatt_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -291,60 +237,15 @@ full_toggled (GtkToggleButton *button, gpointer data)
   				 battstat->fullbattnot, NULL);  
 }
 
-static void
-prefs_help_cb (GtkWindow *dialog)
-{
-	GError *error = NULL;
-	static GnomeProgram *applet_program = NULL;
-	
-	if (!applet_program) {
-		int argc = 1;
-		char *argv[2] = { "battstat" };
-		applet_program = gnome_program_init ("battstat", VERSION,
-						      LIBGNOME_MODULE, argc, argv,
-     						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-	}
-
-	gnome_help_display_desktop_on_screen (
-			applet_program, "battstat", "battstat", "battstatt-prefs",
-			gtk_widget_get_screen (GTK_WIDGET (dialog)),
-			&error);
-
-	if (error) {
-		GtkWidget *error_dialog;
-
-		error_dialog = gtk_message_dialog_new (
-				NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				_("There was an error displaying help: %s"),
-				error->message);
-
-		g_signal_connect (error_dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-
-		gtk_window_set_resizable (GTK_WINDOW (error_dialog), FALSE);
-		gtk_window_set_screen (GTK_WINDOW (error_dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (dialog)));
-		gtk_widget_show (error_dialog);
-		g_error_free (error);
-	}
-}
-
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
-  ProgressData   *battstat = data;
-  
-  if (id == GTK_RESPONSE_HELP) {
-  	prefs_help_cb (GTK_WINDOW (dialog));
-	return;
-  }
-  
-  gtk_widget_hide (GTK_WIDGET (battstat->prop_win));
+  ProgressData *battstat = data;
   
+  if (id == GTK_RESPONSE_HELP)
+    battstat_show_help (battstat, "battstat-appearance");
+  else
+    gtk_widget_hide (GTK_WIDGET (battstat->prop_win));
 }
 
 void
@@ -353,11 +254,12 @@ prop_cb (BonoboUIComponent *uic,
 	 const char        *verb)
 {
   GladeXML  *glade_xml;
-  GtkWidget *layout_table;
+  GtkWidget *combo_ptr, *spin_ptr;
   GConfClient *client;
   GtkListStore *liststore;
   GtkCellRenderer *renderer;
   GtkTreeIter iter;
+  /* Shouldn't this be used for something later on? */
   gboolean   inhibit_command_line;
 
   client = gconf_client_get_default ();
@@ -396,45 +298,44 @@ prop_cb (BonoboUIComponent *uic,
   battstat->hbox_ptr = glade_xml_get_widget (glade_xml, "hbox_ptr");
   hard_set_sensitive (battstat->hbox_ptr, battstat->lowbattnotification);
 
-  battstat->combo_ptr = glade_xml_get_widget (glade_xml, "combo_ptr");
-  g_signal_connect (G_OBJECT (battstat->combo_ptr), "changed",
+  combo_ptr = glade_xml_get_widget (glade_xml, "combo_ptr");
+  g_signal_connect (G_OBJECT (combo_ptr), "changed",
 		  G_CALLBACK (combo_ptr_cb), battstat);
 
   liststore = gtk_list_store_new (1, G_TYPE_STRING);
-  gtk_combo_box_set_model (GTK_COMBO_BOX (battstat->combo_ptr),
+  gtk_combo_box_set_model (GTK_COMBO_BOX (combo_ptr),
 		  GTK_TREE_MODEL (liststore));
-  gtk_cell_layout_clear (GTK_CELL_LAYOUT (battstat->combo_ptr));
+  gtk_cell_layout_clear (GTK_CELL_LAYOUT (combo_ptr));
   renderer = gtk_cell_renderer_text_new ();
-  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (battstat->combo_ptr),
+  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_ptr),
 		  renderer, TRUE);
-  gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (battstat->combo_ptr),
+  gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_ptr),
 		  renderer,
 		  "text", 0,
 		  NULL);
   gtk_list_store_append (liststore, &iter);
-  /* TRANSLATOR: this is the 3rd word in the sentence:
-   *   "Warn when percentage remaining is less then ?? percent"
+  /* TRANSLATOR: this is a selectable item in a drop-down menu to end
+   * this sentence:
+   *   "Warn when battery charge drops to: [XX] percent".
    */
-  gtk_list_store_set (liststore, &iter, 0, _("percentage"), -1);
+  gtk_list_store_set (liststore, &iter, 0, _("Percent"), -1);
   gtk_list_store_append (liststore, &iter);
-  /* TRANSLATOR: this is the 3rd word in the sentence:
-   *   "Warn when time remaining is less then ?? minutes"
+  /* TRANSLATOR: this is a selectable item in a drop-down menu to end
+   * this sentence:
+   *   "Warn when battery charge drops to: [XX] minutes remaining"
    */
-  gtk_list_store_set (liststore, &iter, 0, _("time"), -1);
+  gtk_list_store_set (liststore, &iter, 0, _("Minutes Remaining"), -1);
 
-  battstat->spin_ptr = glade_xml_get_widget (glade_xml, "spin_ptr");
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (battstat->spin_ptr),
+  spin_ptr = glade_xml_get_widget (glade_xml, "spin_ptr");
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_ptr),
 		  battstat->red_val);
-  g_signal_connect (G_OBJECT (battstat->spin_ptr), "value-changed",
+  g_signal_connect (G_OBJECT (spin_ptr), "value-changed",
 		  G_CALLBACK (spin_ptr_cb), battstat);
 
-  battstat->label_ptr = glade_xml_get_widget (glade_xml, "label_ptr");
-
   if (battstat->red_value_is_time)
-	  gtk_combo_box_set_active (GTK_COMBO_BOX (battstat->combo_ptr), 1);
+	  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_ptr), 1);
   else
-	  gtk_combo_box_set_active (GTK_COMBO_BOX (battstat->combo_ptr), 0);
-  set_label_ptr (battstat);
+	  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_ptr), 0);
 
   battstat->full_toggle = glade_xml_get_widget (glade_xml, "full_toggle");
   g_signal_connect (G_OBJECT (battstat->full_toggle), "toggled",
@@ -456,23 +357,6 @@ prop_cb (BonoboUIComponent *uic,
 		    TRUE);
   }
 
-  battstat->suspend_entry = glade_xml_get_widget (glade_xml, "suspend_entry");
-  g_signal_connect (G_OBJECT(battstat->suspend_entry), "changed",
-		    G_CALLBACK(suspend_changed), battstat);
-
-  gtk_entry_set_text (GTK_ENTRY (battstat->suspend_entry),
-		  battstat->suspend_cmd); 
-  
-  if (!key_writable (PANEL_APPLET (battstat->applet), "suspend_command") ||
-      inhibit_command_line)
-  {
-	  hard_set_sensitive (battstat->suspend_entry, FALSE);
-	  hard_set_sensitive (glade_xml_get_widget (glade_xml, "suspend_label"),
-			  FALSE);
-  }
-  
-  layout_table = glade_xml_get_widget (glade_xml, "layout_table");
-
   battstat->radio_traditional_battery = glade_xml_get_widget (glade_xml,
 		  "battery_view_2");
   g_signal_connect (G_OBJECT (battstat->radio_traditional_battery), "toggled",
